import json
from ..models.RantsResponse import RantsResponse

class ResponseHandler:

    def __init__(self):
        self.RantsResponse = RantsResponse()

    def getRantsBuildResponse(self, response):
        deserialized = self.RantsResponse.deserialize(json.loads(response.content))
        return deserialized


from .utils.RequestHandler import RequestHandler
from .utils.ResponseHandler import ResponseHandler

class DevRant:

    def __init__(self):
        self.RequestHandler = RequestHandler()
        self.ResponseHandler = ResponseHandler()

    def getRants(self, sort, limit, skip):
        response = self.RequestHandler.getRants(sort, limit, skip)
        return self.ResponseHandler.getRantsBuildResponse(response)



import colander

class News(colander.MappingSchema):
    id = colander.SchemaNode(colander.Int())
    type = colander.SchemaNode(colander.String())
    headline = colander.SchemaNode(colander.String())
    body = colander.SchemaNode(colander.String())
    footer = colander.SchemaNode(colander.String())
    height = colander.SchemaNode(colander.Int())
    action = colander.SchemaNode(colander.String())


from .UrlBuilder import URLBuilder
import requests

class RequestHandler:
    def __init__(self):
        self.UrlBuilder = URLBuilder()

    def getRants(self, sort, limit, skip):
        url = self.UrlBuilder.getRantURL(sort, limit, skip)
        response = requests.get(url)
        return response


class URLBuilder:
    def __init__(self):
        self.APP_VERSION = 3
        self.BASE_URL = "https://www.devrant.io/api"
        self.RANTS_URL = "%s/devrant/rants?sort=%s&limit=%d&skip=%d&app=%d"
        self.SORT_TOP = "top"
        self.SORT_ALGO = "algo"
        self.SORT_RECENT = "recent"
        self.VALID_SORTS = [self.SORT_ALGO, self.SORT_RECENT, self.SORT_TOP]

    def getRantURL(self, sort, limit, skip):
        if sort == "":
            sort = "top"
        elif sort not in self.VALID_SORTS:
            raise ValueError("Invalid Sort type")
        if limit <= 0 or limit > 100:
            limit = 15
        return str(self.RANTS_URL % (self.BASE_URL, sort, limit, skip, self.APP_VERSION))



from News import News
from Rant import Rants

import colander

class RantsResponse(colander.MappingSchema):
    rants = Rants()
    news = News()
    success = colander.SchemaNode(colander.Boolean())
    error = colander.SchemaNode(colander.Boolean(), missing=colander.drop)
    settings = colander.SchemaNode(colander.String(), missing=colander.drop)
    set = colander.SchemaNode(colander.String())
    wrw = colander.SchemaNode(colander.Int())


import colander

class Rant(colander.MappingSchema):
    id = colander.SchemaNode(colander.Int())
    text = colander.SchemaNode(colander.String())
    score = colander.SchemaNode(colander.Int())
    created_time = colander.SchemaNode(colander.Int())
    user_id = colander.SchemaNode(colander.Int())
    num_comments = colander.SchemaNode(colander.Int())
    user_username = colander.SchemaNode(colander.String())

class Rants(colander.SequenceSchema):
    rants = Rant()


from setuptools import setup
from setuptools import find_packages
setup(
    name='pirant',
    version='0.1.3dev1',
    author = "aayush",
    url="https://github.com/aayush26/pirant",
    license='MIT',
    description = "DevRant wrapper in Python",
    classifiers=[
        'Programming Language :: Python :: 2.7',
    ],
    keywords="devrant api wrapper",
    packages=find_packages(exclude=['contrib', 'docs', 'tests*']),
    install_requires=[
        "colander",
        "requests",
    ]
)